[−][src]Struct tower_lsp::Printer
Sends notifications from the language server to the client.
Methods
impl Printer[src]
pub fn log_message<M: Display>(&self, typ: MessageType, message: M)[src]
Notifies the client to log a particular message.
This corresponds to the window/logMessage notification.
pub fn show_message<M: Display>(&self, typ: MessageType, message: M)[src]
Notifies the client to display a particular message in the user interface.
This corresponds to the window/showMessage notification.
pub fn telemetry_event<S: Serialize>(&self, data: S)[src]
Notifies the client to log a telemetry event.
This corresponds to the telemetry/event notification.
pub fn register_capability(&self, registrations: Vec<Registration>)[src]
Register a new capability with the client.
This corresponds to the client/registerCapability request.
pub fn unregister_capability(&self, unregisterations: Vec<Unregistration>)[src]
Unregister a capability with the client.
This corresponds to the client/unregisterCapability request.
pub fn apply_edit(&self, edit: WorkspaceEdit) -> bool[src]
Requests a workspace resource be edited on the client side and returns whether the edit was applied.
This corresponds to the workspace/applyEdit request.
pub fn publish_diagnostics(
&self,
uri: Url,
diags: Vec<Diagnostic>,
version: Option<i64>
)[src]
&self,
uri: Url,
diags: Vec<Diagnostic>,
version: Option<i64>
)
Submits validation diagnostics for an open file with the given URI.
This corresponds to the textDocument/publishDiagnostics notification.
pub fn send_notification<N>(&self, params: N::Params) where
N: Notification,
N::Params: Serialize, [src]
N: Notification,
N::Params: Serialize,
Sends a custom notification to the client.