[−][src]Struct tower_lsp::LspService
Service abstraction for the Language Server Protocol.
This service takes a JSON-RPC request as input and produces a JSON-RPC response as output. If the incoming request is a notification, then the corresponding response string will be empty.
This implements tower_service::Service in order to remain independent from the underlying
transport and to facilitate further abstraction with middleware.
Methods
impl LspService[src]
pub fn new<T>(server: T) -> (Self, MessageStream) where
T: LanguageServer, [src]
T: LanguageServer,
Creates a new LspService with the given server backend, also returning a stream of
notifications from the server back to the client.
pub fn with_handler<T, U>(server: T, handler: U) -> (Self, MessageStream) where
T: LanguageServer,
U: Into<IoHandler>, [src]
T: LanguageServer,
U: Into<IoHandler>,
Creates a new LspService with the given server backend a custom IoHandler.
ⓘImportant traits for ExitReceiverpub fn close_handle(&self) -> ExitReceiver[src]
Returns a close handle which signals when the exit notification has been received.